from setuptools import setup

setup(name='GTAN_OC_PAC',
      version='0.2',
      description='POCKET',
      packages=['GTAN_OC_PAC'],
      author_email='Arkastar321@mail.ru',
      zip_safe=False)
